@@ -10,7 +10,7 @@ use Carp ();
 sub _path { Path::Tiny::path(@_) }
 
 # ABSTRACT: Specification for defining an external dependency for CPAN
-our $VERSION = '1.78'; # VERSION
+our $VERSION = '1.93'; # VERSION
 
 
 our @EXPORT = qw( requires on plugin probe configure share sys download fetch decode prefer extract patch patch_ffi build build_ffi gather gather_ffi meta_prop ffi log test start_url before after );
@@ -30,7 +30,7 @@ sub requires
 sub plugin
 {
   my($name, @args) = @_;
-  
+
   my $caller = caller;
   $caller->meta->apply_plugin($name, @args);
   return;
@@ -263,9 +263,9 @@ sub test
   my $phase = $meta->{phase};
   Carp::croak "test is not allowed in $phase block"
     if $phase eq 'any' || $phase eq 'configure';
-  
+
   $meta->add_requires('configure' => 'Alien::Build' => '1.14');
-  
+
   if($phase eq 'share')
   {
     my $suffix = $caller->meta->{build_suffix} || '_share';
@@ -322,15 +322,14 @@ sub _add_modifier
   }
 
   foreach my $hook (
-    map { split /,/, $_ }                    # split on , for when multiple hooks must be attachewd (gather in any)
-    map { s/\$/$suffix/; $_ }                # substitute $ at the end for a suffix (_ffi) if any
-    map { "$_" }                             # copy so that we don't subregex on the original
-    $modifiers{$stage}->{$meta->{phase}})    # get the list of modifiers
+    map { split /,/, $_ }                        # split on , for when multiple hooks must be attachewd (gather in any)
+    map { my $x = $_ ; $x =~ s/\$/$suffix/; $x } # substitute $ at the end for a suffix (_ffi) if any
+    $modifiers{$stage}->{$meta->{phase}})        # get the list of modifiers
   {
     $meta->$method($hook => $sub);
   }
 
-  return;  
+  return;
 }
 
 sub before
@@ -369,7 +368,7 @@ alienfile - Specification for defining an external dependency for CPAN
 
 =head1 VERSION
 
-version 1.78
+version 1.93
 
 =head1 SYNOPSIS
 
@@ -380,22 +379,22 @@ Do-it-yourself approach:
  probe [ 'pkg-config --exists libarchive' ];
  
  share {
-   
+ 
    start_url 'http://libarchive.org/downloads/libarchive-3.2.2.tar.gz';
-   
+ 
    # the first one which succeeds will be used
    download [ 'wget %{.meta.start_url}' ];
    download [ 'curl -o %{.meta.start_url}' ];
-   
+ 
    extract [ 'tar xf %{.install.download}' ];
-   
-   build [ 
+ 
+   build [
      # Note: will not work on Windows, better to use Build::Autoconf plugin
      # if you need windows support
      './configure --prefix=%{.install.prefix} --disable-shared',
      '%{make}',
      '%{make} install',
-   ];   
+   ];
  }
  
  gather [
@@ -503,7 +502,7 @@ Examples:
  
  # loads the plugin with the badly named class!
  plugin '=Badly::Named::Plugin::Not::In::Alien::Build::Namespace';
-
+ 
  # explicitly loads Alien::Build::Plugin::Prefer::SortVersions
  plugin 'Prefer::SortVersions => (
    filter => qr/^gcc-.*\.tar\.gz$/,
